@@ -324,7 +324,7 @@ class SecSpyServer:
                 f"Enable/Disable camera failed: {response.status} - Reason: {response.reason}"
             )
 
-        self._processed_data[camera_id]["online"] = enabled
+        self._processed_data[camera_id]["enabled"] = enabled
         return True
 
     def _process_cameras_json(self, json_response, server_id, include_events):
@@ -348,6 +348,7 @@ class SecSpyServer:
             _LOGGER.debug("Processing Camera %s", camera_id)
             if self._is_first_update:
                 self._update_device(camera_id, PROCESSED_EVENT_EMPTY)
+                camera["enabled"] = True
             self._device_state_machine.update(camera_id, camera)
             self._update_device(
                 camera_id,
